==> haskell-ghcide-1.9.1.0-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghcide.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghcide
version:              1.9.1.0
visibility:           public
id:                   ghcide-1.9.1.0-nlODwnzwBaKdohC2wkwFZ
key:                  ghcide-1.9.1.0-nlODwnzwBaKdohC2wkwFZ
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  bb44fb2e64bceaa20aba7534147bf387
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Spans.AtPoint Development.IDE.Spans.Common
    Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Logger
    Development.IDE.Types.Monitoring Development.IDE.Types.Options
    Development.IDE.Types.Shake Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.0.2/site-local/ghcide-1.9.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/ghcide-1.9.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-1.9.1.0-nlODwnzwBaKdohC2wkwFZ
depends:
    Diff-0.4.1-EqwEB8DTOF3If1stmvUw5L
    Glob-0.10.2-4EgomKOxVtXIhrgXo85cWZ
    aeson-2.1.2.1-9eMlWz33g2YChqrYmLCdHv
    aeson-pretty-0.8.9-2phVOfyOkBK5YZD1AxoEBG array-0.5.4.0
    async-2.2.5-FrngEs5mK8IFeImBJauzWE base-4.15.1.0
    base16-bytestring-1.0.2.0-BDPRkjjRTWN9vghagmfU97 binary-0.8.8.0
    bytestring-0.10.12.1
    case-insensitive-1.2.1.0-FVZgYYSN0UQ2LiRksrpHvU
    co-log-core-0.3.2.1-1YF1uWiMZAtDDx8DXliMjx containers-0.6.4.1
    cryptohash-sha1-0.11.101.0-J0ppHlx3SfE6eNmGJ99lSW
    data-default-0.7.1.1-4W3DdpWCDdz1ZSimKMWhuv deepseq-1.4.5.0
    dependent-map-0.4.0.0-57RPDxlYbpa4udJ6NnFbiQ
    dependent-sum-0.7.2.0-FV1lD6Dc1cA5KIeILxuxRB directory-1.3.6.2
    dlist-1.0-Ge5E4TM9DngAWe8aSUgFvB
    enummapset-0.7.2.0-52GS60nl5vy3Bpl6xyTx8l exceptions-0.10.4
    extra-1.7.14-B9l56eYVJTU9jIIUy6ZiPT filepath-1.4.2.1
    fingertree-0.1.5.0-82mxSFKVcEuKnEbT5RffJP
    focus-1.0.3.2-7gFNJ7bmuKFCfpilDgdPMa ghc-9.0.2 ghc-boot-9.0.2
    ghc-boot-th-9.0.2 ghc-check-0.5.0.8-FkUiwXO59sXACbssIolm3X
    ghc-paths-0.1.0.12-7fRPaqGgnC488dNzs2elDi
    ghc-trace-events-0.1.2.7-KqL0Q6Rsn8A7qIYdrbRLC8
    haddock-library-1.10.0-KKn2fUsGbptsKNe1i9IwH
    hashable-1.4.3.0-GjMDKgDyLuqLq9SaBPRy7H
    hie-bios-0.11.0-9Bsh2ZQaqWbHYQfQDuD723
    hie-compat-0.3.0.0-HtRpwVRm0jbBmBGDkwMYdm
    hiedb-0.4.2.0-Egmo2wdoNIKCpF2tsDggxX
    hls-graph-1.9.0.0-5K7ROVgdEpF8a3y39k5yXu
    hls-plugin-api-1.6.0.0-E1OTGSnPOpBAN8WYkQIhz7
    hslogger-1.3.1.0-CaMLskj0eig8qIjBFU5vgX
    implicit-hie-0.1.2.7-JgEIFKoufndBjPYUaPr5v9
    implicit-hie-cradle-0.3.0.5-Eoh30FsRLnO3OvGuPyGcW6
    lens-5.2.3-87VVzdxB0Km6KR6RgyjfEc
    list-t-1.0.5.4-DIydZMmRHBBAuUE7ymfOrx
    lsp-1.6.0.0-I48PXoCjRiIIfQ6JCpUbdL
    lsp-types-1.6.0.0-1SDSUu9um8DDAz9sUpiZnq mtl-2.2.2
    opentelemetry-0.8.0-J7JOASAZTbG5vGgzDfsnM
    optparse-applicative-0.17.1.0-AxEI8mDLbJi7Q5pwqU28ta
    parallel-3.2.2.0-D2aleEa2VnPBr164BdKnms
    prettyprinter-1.7.1-1n7eM1GDn4mHKz0GOou7LC
    prettyprinter-ansi-terminal-1.1.3-BeenYf8Pos1FwI6L1g5bOd
    random-1.2.1.1-C6YbKOqj1b9FtHcTQfM70Q
    regex-tdfa-1.3.2.2-KwKZdselX0YCKPlJsADo8Z
    safe-exceptions-0.1.7.4-Jwtf01ie8c53vwayySjWH1
    sorted-list-0.2.2.0-8JyvDFRyjEfAcOVyZlT14l
    sqlite-simple-0.4.18.2-4yHKlRMjZjT9RqmilVDQdl stm-2.5.0.0
    stm-containers-1.2.0.3-Ksfmu4PQJcvB7yygUQZMTA
    syb-0.7.2.3-HTIpzyBWTd85gpck08Ij6s text-1.2.5.0
    text-rope-0.2-28PwU4ke84Y2wIbzuSU2sD time-1.9.3
    transformers-0.5.6.2 unix-2.7.2.2
    unliftio-0.2.25.0-3KLPdpqwawq1LMcNrWCiEc
    unliftio-core-0.2.1.0-AJ3ipHGgln87h2Y2hfrpJj
    unordered-containers-0.2.20-I0fO2F07bWBHt2ZuPKJLVg
    vector-0.13.1.0-BQe94mmHcwnGaa4dX3J4G3

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghcide-1.9.1.0-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghcide.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghcide
version:              1.9.1.0
visibility:           public
id:                   ghcide-1.9.1.0-4v981bncGfv7lGvePtfxX
key:                  ghcide-1.9.1.0-4v981bncGfv7lGvePtfxX
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  e4242b9bc75c9ea56b14bd3d129d12a7
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Spans.AtPoint Development.IDE.Spans.Common
    Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Logger
    Development.IDE.Types.Monitoring Development.IDE.Types.Options
    Development.IDE.Types.Shake Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.0.2/site-local/ghcide-1.9.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/ghcide-1.9.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-1.9.1.0-4v981bncGfv7lGvePtfxX
depends:
    Diff-0.4.1-2LnAKth0B0C6AiE7scI6Lx
    Glob-0.10.2-CVKxzEtxqmm4O6paIXQOzx
    aeson-2.1.2.1-7LyJDTguS534hsqA6ST8CG
    aeson-pretty-0.8.9-68rxgn4DhUx8WACn3KmZqv array-0.5.4.0
    async-2.2.5-40NuXQV9qfeBYZFVwp7YdO base-4.15.1.0
    base16-bytestring-1.0.2.0-4eJF9rLIoxiDCZFbu3SGUI binary-0.8.8.0
    bytestring-0.10.12.1
    case-insensitive-1.2.1.0-1QZbpDldMAwJ0u4VaHLZSP
    co-log-core-0.3.2.1-5A85WdPasIVsO1HPmgx6D containers-0.6.4.1
    cryptohash-sha1-0.11.101.0-HK0AN7VQMCb3GI9V1I4Cwl
    data-default-0.7.1.1-4W3DdpWCDdz1ZSimKMWhuv deepseq-1.4.5.0
    dependent-map-0.4.0.0-K9BZCGAmFNQLvyjA9JQeTk
    dependent-sum-0.7.2.0-36fTui7ct0kCqWruPRJRQo directory-1.3.6.2
    dlist-1.0-Ge5E4TM9DngAWe8aSUgFvB
    enummapset-0.7.2.0-9dUF6ROPPBcGeDXffItu2j exceptions-0.10.4
    extra-1.7.14-LeGtA61kank1nfrcvwQEPL filepath-1.4.2.1
    fingertree-0.1.5.0-7WSbFUc1THzBIgdcdzIbYF
    focus-1.0.3.2-C8lzIAFQWHgJ7aieshON70 ghc-9.0.2 ghc-boot-9.0.2
    ghc-boot-th-9.0.2 ghc-check-0.5.0.8-5xWtA3jNZmXKzs7XJ5ycrP
    ghc-paths-0.1.0.12-7fRPaqGgnC488dNzs2elDi
    ghc-trace-events-0.1.2.7-KqL0Q6Rsn8A7qIYdrbRLC8
    haddock-library-1.11.0-IgS8QR694jnlpQAijQWD8
    hashable-1.4.3.0-LTYvL1TeA7ZGWACRCRhioS
    hie-bios-0.11.0-Khuc1MW0AqkoWBnUxPt15
    hie-compat-0.3.0.0-HtRpwVRm0jbBmBGDkwMYdm
    hiedb-0.4.2.0-JsYTHcNPBS8358d8hOf23a
    hls-graph-1.9.0.0-8rc4mggaHG39e11qtvWK8I
    hls-plugin-api-1.6.0.0-EoAGZxnzRUr7h0wQJlGdxB
    hslogger-1.3.1.0-HrNv6dKFDOJAzbK6DqBzu9
    implicit-hie-0.1.2.7-5G95qMsQKxS3AVnBs8k2V9
    implicit-hie-cradle-0.5.0.0-GgVHKIO9qtj67kLr8LyU44
    lens-5.2.3-1K0t4JcebKa7pTTCdAolg0
    list-t-1.0.5.4-BsxsCYHmpq9CMVpOK0pZNx
    lsp-1.6.0.0-4RlMBMQeaME3rXSRggJdLR
    lsp-types-1.6.0.0-LcX10m8dcUU17ekeKy9nqF mtl-2.2.2
    opentelemetry-0.8.0-ISBKa0RT0Lo9aHLVwc6umY
    optparse-applicative-0.17.1.0-1JW3OZYtiEdH6bqzIth6E8
    parallel-3.2.2.0-D2aleEa2VnPBr164BdKnms
    prettyprinter-1.7.1-Em8DfLhSU5d798OW7UB5I1
    prettyprinter-ansi-terminal-1.1.3-5TTDZ0XX2y7GVp57xaWvrA
    random-1.2.1.1-DrFR13f98YX89cHWEcJzgn
    regex-tdfa-1.3.2.2-BRUpw2GH1gw8Qr5MRZI8Fw
    safe-exceptions-0.1.7.4-Lt7ec6TMmQBLMwDpOXWEMv
    sorted-list-0.2.2.0-JQDGoaZuEng5eGwMLG3mcc
    sqlite-simple-0.4.18.2-Kj6dWNfV06J6To4m244X3B stm-2.5.0.0
    stm-containers-1.2.0.3-6vJ8Ai4hyTNLKdFuc1Ox4O
    syb-0.7.2.3-AEwAwBgIma0CprpIrUW7Zd text-1.2.5.0
    text-rope-0.2-8tkGgDTMtA23rMCDbZ8pDM time-1.9.3
    transformers-0.5.6.2 unix-2.7.2.2
    unliftio-0.2.25.0-FtWWkeZ0kbY15e6nnkXPsK
    unliftio-core-0.2.1.0-AJ3ipHGgln87h2Y2hfrpJj
    unordered-containers-0.2.20-4StCMeLaaOuLlwIEVhKcOQ
    vector-0.13.1.0-Gln8OENDMO9930xazGqCnl

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
